@@ -17,6 +17,8 @@ from .const import GROUP_ID_ADMIN, GROUP_ID_READ_ONLY, GROUP_ID_USER
 from .permissions import PermissionLookup, system_policies
 from .permissions.types import PolicyType
 
+# mypy: disallow-any-generics
+
 STORAGE_VERSION = 1
 STORAGE_KEY = "auth"
 GROUP_NAME_ADMIN = "Administrators"
@@ -94,8 +96,7 @@ class AuthStore:
 
         groups = []
         for group_id in group_ids or []:
-            group = self._groups.get(group_id)
-            if group is None:
+            if (group := self._groups.get(group_id)) is None:
                 raise ValueError(f"Invalid group specified {group_id}")
             groups.append(group)
 
@@ -158,8 +159,7 @@ class AuthStore:
         if group_ids is not None:
             groups = []
             for grid in group_ids:
-                group = self._groups.get(grid)
-                if group is None:
+                if (group := self._groups.get(grid)) is None:
                     raise ValueError("Invalid group specified.")
                 groups.append(group)
 
@@ -444,16 +444,14 @@ class AuthStore:
                 )
                 continue
 
-            token_type = rt_dict.get("token_type")
-            if token_type is None:
+            if (token_type := rt_dict.get("token_type")) is None:
                 if rt_dict["client_id"] is None:
                     token_type = models.TOKEN_TYPE_SYSTEM
                 else:
                     token_type = models.TOKEN_TYPE_NORMAL
 
             # old refresh_token don't have last_used_at (pre-0.78)
-            last_used_at_str = rt_dict.get("last_used_at")
-            if last_used_at_str:
+            if last_used_at_str := rt_dict.get("last_used_at"):
                 last_used_at = dt_util.parse_datetime(last_used_at_str)
             else:
                 last_used_at = None
@@ -491,7 +489,7 @@ class AuthStore:
         self._store.async_delay_save(self._data_to_save, 1)
 
     @callback
-    def _data_to_save(self) -> dict:
+    def _data_to_save(self) -> dict[str, list[dict[str, Any]]]:
         """Return the data to store."""
         assert self._users is not None
         assert self._groups is not None
