@@ -19,7 +19,6 @@ from homeassistant.components.weather import (
 from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_NAME, TEMP_CELSIUS, TEMP_FAHRENHEIT
 from homeassistant.core import HomeAssistant
-from homeassistant.helpers.entity import DeviceInfo
 from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 from homeassistant.util.dt import utc_from_timestamp
@@ -60,29 +59,15 @@ class AccuWeatherEntity(CoordinatorEntity, WeatherEntity):
     ) -> None:
         """Initialize."""
         super().__init__(coordinator)
-        self._name = name
-        self._unit_system = API_METRIC if self.coordinator.is_metric else API_IMPERIAL
-
-    @property
-    def name(self) -> str:
-        """Return the name."""
-        return self._name
-
-    @property
-    def attribution(self) -> str:
-        """Return the attribution."""
-        return ATTRIBUTION
-
-    @property
-    def unique_id(self) -> str:
-        """Return a unique_id for this entity."""
-        return self.coordinator.location_key
-
-    @property
-    def device_info(self) -> DeviceInfo:
-        """Return the device info."""
-        return {
-            "identifiers": {(DOMAIN, self.coordinator.location_key)},
+        self._unit_system = API_METRIC if coordinator.is_metric else API_IMPERIAL
+        self._attr_name = name
+        self._attr_unique_id = coordinator.location_key
+        self._attr_temperature_unit = (
+            TEMP_CELSIUS if coordinator.is_metric else TEMP_FAHRENHEIT
+        )
+        self._attr_attribution = ATTRIBUTION
+        self._attr_device_info = {
+            "identifiers": {(DOMAIN, coordinator.location_key)},
             "name": NAME,
             "manufacturer": MANUFACTURER,
             "entry_type": "service",
@@ -107,11 +92,6 @@ class AccuWeatherEntity(CoordinatorEntity, WeatherEntity):
             float, self.coordinator.data["Temperature"][self._unit_system]["Value"]
         )
 
-    @property
-    def temperature_unit(self) -> str:
-        """Return the unit of measurement."""
-        return TEMP_CELSIUS if self.coordinator.is_metric else TEMP_FAHRENHEIT
-
     @property
     def pressure(self) -> float:
         """Return the pressure."""
