@@ -1,4 +1,5 @@
 """Support for Acmeda Roller Blind Batteries."""
+from homeassistant.components.sensor import SensorEntity
 from homeassistant.const import DEVICE_CLASS_BATTERY, PERCENTAGE
 from homeassistant.core import callback
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -29,11 +30,11 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
     )
 
 
-class AcmedaBattery(AcmedaBase):
+class AcmedaBattery(AcmedaBase, SensorEntity):
     """Representation of a Acmeda cover device."""
 
     device_class = DEVICE_CLASS_BATTERY
-    unit_of_measurement = PERCENTAGE
+    _attr_native_unit_of_measurement = PERCENTAGE
 
     @property
     def name(self):
@@ -41,6 +42,6 @@ class AcmedaBattery(AcmedaBase):
         return f"{super().name} Battery"
 
     @property
-    def state(self):
+    def native_value(self):
         """Return the state of the device."""
         return self.roller.battery
