@@ -141,7 +141,7 @@ class ArestSensor(SensorEntity):
         self.arest = arest
         self._attr_name = f"{location.title()} {name.title()}"
         self._variable = variable
-        self._attr_unit_of_measurement = unit_of_measurement
+        self._attr_native_unit_of_measurement = unit_of_measurement
         self._renderer = renderer
 
         if pin is not None:
@@ -155,9 +155,9 @@ class ArestSensor(SensorEntity):
         self._attr_available = self.arest.available
         values = self.arest.data
         if "error" in values:
-            self._attr_state = values["error"]
+            self._attr_native_value = values["error"]
         else:
-            self._attr_state = self._renderer(
+            self._attr_native_value = self._renderer(
                 values.get("value", values.get(self._variable, None))
             )
 
