@@ -81,7 +81,7 @@ async def async_setup(hass, config):
     options = {}
     mode = conf.get(CONF_MODE, MODE_ROUTER)
     for name, value in conf.items():
-        if name in ([CONF_DNSMASQ, CONF_INTERFACE, CONF_REQUIRE_IP]):
+        if name in [CONF_DNSMASQ, CONF_INTERFACE, CONF_REQUIRE_IP]:
             if name == CONF_REQUIRE_IP and mode != MODE_AP:
                 continue
             options[name] = value
@@ -111,7 +111,7 @@ async def async_setup(hass, config):
     return True
 
 
-async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry):
+async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up AsusWrt platform."""
 
     # import options from yaml if empty
