@@ -1,19 +1,25 @@
 """Component to interface with binary sensors."""
+from __future__ import annotations
 
+from dataclasses import dataclass
 from datetime import timedelta
 import logging
+from typing import Any, final
 
 import voluptuous as vol
 
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import STATE_OFF, STATE_ON
+from homeassistant.core import HomeAssistant
 from homeassistant.helpers.config_validation import (  # noqa: F401
     PLATFORM_SCHEMA,
     PLATFORM_SCHEMA_BASE,
 )
-from homeassistant.helpers.entity import Entity
+from homeassistant.helpers.entity import Entity, EntityDescription
 from homeassistant.helpers.entity_component import EntityComponent
+from homeassistant.helpers.typing import ConfigType, StateType
 
-# mypy: allow-untyped-defs, no-check-untyped-defs
+_LOGGER = logging.getLogger(__name__)
 
 DOMAIN = "binary_sensor"
 SCAN_INTERVAL = timedelta(seconds=30)
@@ -23,6 +29,9 @@ ENTITY_ID_FORMAT = DOMAIN + ".{}"
 # On means low, Off means normal
 DEVICE_CLASS_BATTERY = "battery"
 
+# On means charging, Off means not charging
+DEVICE_CLASS_BATTERY_CHARGING = "battery_charging"
+
 # On means cold, Off means normal
 DEVICE_CLASS_COLD = "cold"
 
@@ -83,6 +92,9 @@ DEVICE_CLASS_SMOKE = "smoke"
 # On means sound detected, Off means no sound (clear)
 DEVICE_CLASS_SOUND = "sound"
 
+# On means update available, Off means up-to-date
+DEVICE_CLASS_UPDATE = "update"
+
 # On means vibration detected, Off means no vibration
 DEVICE_CLASS_VIBRATION = "vibration"
 
@@ -91,6 +103,7 @@ DEVICE_CLASS_WINDOW = "window"
 
 DEVICE_CLASSES = [
     DEVICE_CLASS_BATTERY,
+    DEVICE_CLASS_BATTERY_CHARGING,
     DEVICE_CLASS_COLD,
     DEVICE_CLASS_CONNECTIVITY,
     DEVICE_CLASS_DOOR,
@@ -111,6 +124,7 @@ DEVICE_CLASSES = [
     DEVICE_CLASS_SAFETY,
     DEVICE_CLASS_SMOKE,
     DEVICE_CLASS_SOUND,
+    DEVICE_CLASS_UPDATE,
     DEVICE_CLASS_VIBRATION,
     DEVICE_CLASS_WINDOW,
 ]
@@ -118,7 +132,7 @@ DEVICE_CLASSES = [
 DEVICE_CLASSES_SCHEMA = vol.All(vol.Lower, vol.In(DEVICE_CLASSES))
 
 
-async def async_setup(hass, config):
+async def async_setup(hass: HomeAssistant, config: ConfigType) -> bool:
     """Track states and offer events for binary sensors."""
     component = hass.data[DOMAIN] = EntityComponent(
         logging.getLogger(__name__), DOMAIN, hass, SCAN_INTERVAL
@@ -128,30 +142,49 @@ async def async_setup(hass, config):
     return True
 
 
-async def async_setup_entry(hass, entry):
+async def async_setup_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Set up a config entry."""
-    return await hass.data[DOMAIN].async_setup_entry(entry)
+    component: EntityComponent = hass.data[DOMAIN]
+    return await component.async_setup_entry(entry)
 
 
-async def async_unload_entry(hass, entry):
+async def async_unload_entry(hass: HomeAssistant, entry: ConfigEntry) -> bool:
     """Unload a config entry."""
-    return await hass.data[DOMAIN].async_unload_entry(entry)
+    component: EntityComponent = hass.data[DOMAIN]
+    return await component.async_unload_entry(entry)
 
 
-class BinarySensorDevice(Entity):
+@dataclass
+class BinarySensorEntityDescription(EntityDescription):
+    """A class that describes binary sensor entities."""
+
+
+class BinarySensorEntity(Entity):
     """Represent a binary sensor."""
 
-    @property
-    def is_on(self):
-        """Return true if the binary sensor is on."""
-        return None
+    entity_description: BinarySensorEntityDescription
+    _attr_is_on: bool | None = None
+    _attr_state: None = None
 
     @property
-    def state(self):
+    def is_on(self) -> bool | None:
+        """Return true if the binary sensor is on."""
+        return self._attr_is_on
+
+    @final
+    @property
+    def state(self) -> StateType:
         """Return the state of the binary sensor."""
         return STATE_ON if self.is_on else STATE_OFF
 
-    @property
-    def device_class(self):
-        """Return the class of this device, from component DEVICE_CLASSES."""
-        return None
+
+class BinarySensorDevice(BinarySensorEntity):
+    """Represent a binary sensor (for backwards compatibility)."""
+
+    def __init_subclass__(cls, **kwargs: Any):
+        """Print deprecation warning."""
+        super().__init_subclass__(**kwargs)  # type: ignore[call-arg]
+        _LOGGER.warning(
+            "BinarySensorDevice is deprecated, modify %s to extend BinarySensorEntity",
+            cls.__name__,
+        )
