@@ -18,7 +18,7 @@ from homeassistant.util import Throttle
 
 _LOGGER = logging.getLogger(__name__)
 
-BLOOMSKY_TYPE = ["camera", "binary_sensor", "sensor"]
+PLATFORMS = ["camera", "binary_sensor", "sensor"]
 
 DOMAIN = "bloomsky"
 
@@ -32,7 +32,7 @@ CONFIG_SCHEMA = vol.Schema(
 
 
 def setup(hass, config):
-    """Set up the BloomSky component."""
+    """Set up the BloomSky integration."""
     api_key = config[DOMAIN][CONF_API_KEY]
 
     try:
@@ -42,8 +42,8 @@ def setup(hass, config):
 
     hass.data[DOMAIN] = bloomsky
 
-    for component in BLOOMSKY_TYPE:
-        discovery.load_platform(hass, component, DOMAIN, {}, config)
+    for platform in PLATFORMS:
+        discovery.load_platform(hass, platform, DOMAIN, {}, config)
 
     return True
 
@@ -60,7 +60,7 @@ class BloomSky:
         self._endpoint_argument = "unit=intl" if is_metric else ""
         self.devices = {}
         self.is_metric = is_metric
-        _LOGGER.debug("Initial BloomSky device load...")
+        _LOGGER.debug("Initial BloomSky device load")
         self.refresh_devices()
 
     @Throttle(MIN_TIME_BETWEEN_UPDATES)
