@@ -87,154 +87,154 @@ SENSOR_TYPES: Final[tuple[SensorEntityDescription, ...]] = (
         key=ATTR_PAGE_COUNTER,
         icon="mdi:file-document-outline",
         name=ATTR_PAGE_COUNTER.replace("_", " ").title(),
-        unit_of_measurement=UNIT_PAGES,
+        native_unit_of_measurement=UNIT_PAGES,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BW_COUNTER,
         icon="mdi:file-document-outline",
         name=ATTR_BW_COUNTER.replace("_", " ").title(),
-        unit_of_measurement=UNIT_PAGES,
+        native_unit_of_measurement=UNIT_PAGES,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_COLOR_COUNTER,
         icon="mdi:file-document-outline",
         name=ATTR_COLOR_COUNTER.replace("_", " ").title(),
-        unit_of_measurement=UNIT_PAGES,
+        native_unit_of_measurement=UNIT_PAGES,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_DUPLEX_COUNTER,
         icon="mdi:file-document-outline",
         name=ATTR_DUPLEX_COUNTER.replace("_", " ").title(),
-        unit_of_measurement=UNIT_PAGES,
+        native_unit_of_measurement=UNIT_PAGES,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_DRUM_REMAINING_LIFE,
         icon="mdi:chart-donut",
         name=ATTR_DRUM_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BLACK_DRUM_REMAINING_LIFE,
         icon="mdi:chart-donut",
         name=ATTR_BLACK_DRUM_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_CYAN_DRUM_REMAINING_LIFE,
         icon="mdi:chart-donut",
         name=ATTR_CYAN_DRUM_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_MAGENTA_DRUM_REMAINING_LIFE,
         icon="mdi:chart-donut",
         name=ATTR_MAGENTA_DRUM_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_YELLOW_DRUM_REMAINING_LIFE,
         icon="mdi:chart-donut",
         name=ATTR_YELLOW_DRUM_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BELT_UNIT_REMAINING_LIFE,
         icon="mdi:current-ac",
         name=ATTR_BELT_UNIT_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_FUSER_REMAINING_LIFE,
         icon="mdi:water-outline",
         name=ATTR_FUSER_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_LASER_REMAINING_LIFE,
         icon="mdi:spotlight-beam",
         name=ATTR_LASER_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_PF_KIT_1_REMAINING_LIFE,
         icon="mdi:printer-3d",
         name=ATTR_PF_KIT_1_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_PF_KIT_MP_REMAINING_LIFE,
         icon="mdi:printer-3d",
         name=ATTR_PF_KIT_MP_REMAINING_LIFE.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BLACK_TONER_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_BLACK_TONER_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_CYAN_TONER_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_CYAN_TONER_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_MAGENTA_TONER_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_MAGENTA_TONER_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_YELLOW_TONER_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_YELLOW_TONER_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_BLACK_INK_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_BLACK_INK_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_CYAN_INK_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_CYAN_INK_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_MAGENTA_INK_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_MAGENTA_INK_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
         key=ATTR_YELLOW_INK_REMAINING,
         icon="mdi:printer-3d-nozzle",
         name=ATTR_YELLOW_INK_REMAINING.replace("_", " ").title(),
-        unit_of_measurement=PERCENTAGE,
+        native_unit_of_measurement=PERCENTAGE,
         state_class=STATE_CLASS_MEASUREMENT,
     ),
     SensorEntityDescription(
