@@ -11,7 +11,6 @@ from buienradar.constants import (
     WINDAZIMUTH,
     WINDSPEED,
 )
-import voluptuous as vol
 
 from homeassistant.components.weather import (
     ATTR_CONDITION_CLOUDY,
@@ -35,59 +34,58 @@ from homeassistant.components.weather import (
     ATTR_FORECAST_TIME,
     ATTR_FORECAST_WIND_BEARING,
     ATTR_FORECAST_WIND_SPEED,
-    PLATFORM_SCHEMA,
     WeatherEntity,
 )
+from homeassistant.config_entries import ConfigEntry
 from homeassistant.const import CONF_LATITUDE, CONF_LONGITUDE, CONF_NAME, TEMP_CELSIUS
-from homeassistant.helpers import config_validation as cv
+from homeassistant.core import HomeAssistant
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
 
 # Reuse data and API logic from the sensor implementation
-from .const import DEFAULT_TIMEFRAME
+from .const import DEFAULT_TIMEFRAME, DOMAIN
 from .util import BrData
 
 _LOGGER = logging.getLogger(__name__)
 
-DATA_CONDITION = "buienradar_condition"
-
-
 CONF_FORECAST = "forecast"
 
+DATA_CONDITION = "buienradar_condition"
 
 CONDITION_CLASSES = {
-    ATTR_CONDITION_CLOUDY: ["c", "p"],
-    ATTR_CONDITION_FOG: ["d", "n"],
-    ATTR_CONDITION_HAIL: [],
-    ATTR_CONDITION_LIGHTNING: ["g"],
-    ATTR_CONDITION_LIGHTNING_RAINY: ["s"],
-    ATTR_CONDITION_PARTLYCLOUDY: ["b", "j", "o", "r"],
-    ATTR_CONDITION_POURING: ["l", "q"],
-    ATTR_CONDITION_RAINY: ["f", "h", "k", "m"],
-    ATTR_CONDITION_SNOWY: ["u", "i", "v", "t"],
-    ATTR_CONDITION_SNOWY_RAINY: ["w"],
-    ATTR_CONDITION_SUNNY: ["a"],
-    ATTR_CONDITION_WINDY: [],
-    ATTR_CONDITION_WINDY_VARIANT: [],
-    ATTR_CONDITION_EXCEPTIONAL: [],
+    ATTR_CONDITION_CLOUDY: ("c", "p"),
+    ATTR_CONDITION_FOG: ("d", "n"),
+    ATTR_CONDITION_HAIL: (),
+    ATTR_CONDITION_LIGHTNING: ("g",),
+    ATTR_CONDITION_LIGHTNING_RAINY: ("s",),
+    ATTR_CONDITION_PARTLYCLOUDY: (
+        "b",
+        "j",
+        "o",
+        "r",
+    ),
+    ATTR_CONDITION_POURING: ("l", "q"),
+    ATTR_CONDITION_RAINY: ("f", "h", "k", "m"),
+    ATTR_CONDITION_SNOWY: ("u", "i", "v", "t"),
+    ATTR_CONDITION_SNOWY_RAINY: ("w",),
+    ATTR_CONDITION_SUNNY: ("a",),
+    ATTR_CONDITION_WINDY: (),
+    ATTR_CONDITION_WINDY_VARIANT: (),
+    ATTR_CONDITION_EXCEPTIONAL: (),
 }
 
-PLATFORM_SCHEMA = PLATFORM_SCHEMA.extend(
-    {
-        vol.Optional(CONF_NAME): cv.string,
-        vol.Optional(CONF_LATITUDE): cv.latitude,
-        vol.Optional(CONF_LONGITUDE): cv.longitude,
-        vol.Optional(CONF_FORECAST, default=True): cv.boolean,
-    }
-)
 
-
-async def async_setup_platform(hass, config, async_add_entities, discovery_info=None):
+async def async_setup_entry(
+    hass: HomeAssistant, entry: ConfigEntry, async_add_entities: AddEntitiesCallback
+) -> None:
     """Set up the buienradar platform."""
+    config = entry.data
+
     latitude = config.get(CONF_LATITUDE, hass.config.latitude)
     longitude = config.get(CONF_LONGITUDE, hass.config.longitude)
 
     if None in (latitude, longitude):
         _LOGGER.error("Latitude or longitude not set in Home Assistant config")
-        return False
+        return
 
     coordinates = {CONF_LATITUDE: float(latitude), CONF_LONGITUDE: float(longitude)}
 
@@ -97,12 +95,12 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
     _LOGGER.debug("Initializing buienradar weather: coordinates %s", coordinates)
 
     # create condition helper
-    if DATA_CONDITION not in hass.data:
+    if DATA_CONDITION not in hass.data[DOMAIN]:
         cond_keys = [str(chr(x)) for x in range(97, 123)]
-        hass.data[DATA_CONDITION] = dict.fromkeys(cond_keys)
+        hass.data[DOMAIN][DATA_CONDITION] = dict.fromkeys(cond_keys)
         for cond, condlst in CONDITION_CLASSES.items():
             for condi in condlst:
-                hass.data[DATA_CONDITION][condi] = cond
+                hass.data[DOMAIN][DATA_CONDITION][condi] = cond
 
     async_add_entities([BrWeather(data, config, coordinates)])
 
@@ -113,13 +111,17 @@ async def async_setup_platform(hass, config, async_add_entities, discovery_info=
 class BrWeather(WeatherEntity):
     """Representation of a weather condition."""
 
+    _attr_temperature_unit = TEMP_CELSIUS
+
     def __init__(self, data, config, coordinates):
-        """Initialise the platform with a data instance and station name."""
-        self._stationname = config.get(CONF_NAME)
-        self._forecast = config[CONF_FORECAST]
+        """Initialize the platform with a data instance and station name."""
+        self._stationname = config.get(CONF_NAME, "Buienradar")
+        self._attr_name = (
+            self._stationname or f"BR {data.stationname or '(unknown station)'}"
+        )
         self._data = data
 
-        self._unique_id = "{:2.6f}{:2.6f}".format(
+        self._attr_unique_id = "{:2.6f}{:2.6f}".format(
             coordinates[CONF_LATITUDE], coordinates[CONF_LONGITUDE]
         )
 
@@ -128,20 +130,13 @@ class BrWeather(WeatherEntity):
         """Return the attribution."""
         return self._data.attribution
 
-    @property
-    def name(self):
-        """Return the name of the sensor."""
-        return (
-            self._stationname or f"BR {self._data.stationname or '(unknown station)'}"
-        )
-
     @property
     def condition(self):
         """Return the current condition."""
         if self._data and self._data.condition:
             ccode = self._data.condition.get(CONDCODE)
             if ccode:
-                conditions = self.hass.data.get(DATA_CONDITION)
+                conditions = self.hass.data[DOMAIN].get(DATA_CONDITION)
                 if conditions:
                     return conditions.get(ccode)
 
@@ -179,19 +174,11 @@ class BrWeather(WeatherEntity):
         """Return the current wind bearing (degrees)."""
         return self._data.wind_bearing
 
-    @property
-    def temperature_unit(self):
-        """Return the unit of measurement."""
-        return TEMP_CELSIUS
-
     @property
     def forecast(self):
         """Return the forecast array."""
-        if not self._forecast:
-            return None
-
         fcdata_out = []
-        cond = self.hass.data[DATA_CONDITION]
+        cond = self.hass.data[DOMAIN][DATA_CONDITION]
 
         if not self._data.forecast:
             return None
@@ -213,8 +200,3 @@ class BrWeather(WeatherEntity):
             fcdata_out.append(data_out)
 
         return fcdata_out
-
-    @property
-    def unique_id(self):
-        """Return the unique id."""
-        return self._unique_id
