@@ -1,9 +1,14 @@
 """Support for Canary alarm."""
 from __future__ import annotations
 
-from typing import Callable
+from typing import Any
 
-from canary.api import LOCATION_MODE_AWAY, LOCATION_MODE_HOME, LOCATION_MODE_NIGHT
+from canary.api import (
+    LOCATION_MODE_AWAY,
+    LOCATION_MODE_HOME,
+    LOCATION_MODE_NIGHT,
+    Location,
+)
 
 from homeassistant.components.alarm_control_panel import AlarmControlPanelEntity
 from homeassistant.components.alarm_control_panel.const import (
@@ -18,8 +23,8 @@ from homeassistant.const import (
     STATE_ALARM_ARMED_NIGHT,
     STATE_ALARM_DISARMED,
 )
-from homeassistant.helpers.entity import Entity
-from homeassistant.helpers.typing import HomeAssistantType
+from homeassistant.core import HomeAssistant
+from homeassistant.helpers.entity_platform import AddEntitiesCallback
 from homeassistant.helpers.update_coordinator import CoordinatorEntity
 
 from .const import DATA_COORDINATOR, DOMAIN
@@ -27,9 +32,9 @@ from .coordinator import CanaryDataUpdateCoordinator
 
 
 async def async_setup_entry(
-    hass: HomeAssistantType,
+    hass: HomeAssistant,
     entry: ConfigEntry,
-    async_add_entities: Callable[[list[Entity], bool], None],
+    async_add_entities: AddEntitiesCallback,
 ) -> None:
     """Set up Canary alarm control panels based on a config entry."""
     coordinator: CanaryDataUpdateCoordinator = hass.data[DOMAIN][entry.entry_id][
@@ -46,29 +51,27 @@ async def async_setup_entry(
 class CanaryAlarm(CoordinatorEntity, AlarmControlPanelEntity):
     """Representation of a Canary alarm control panel."""
 
-    def __init__(self, coordinator, location):
+    coordinator: CanaryDataUpdateCoordinator
+    _attr_supported_features = (
+        SUPPORT_ALARM_ARM_HOME | SUPPORT_ALARM_ARM_AWAY | SUPPORT_ALARM_ARM_NIGHT
+    )
+
+    def __init__(
+        self, coordinator: CanaryDataUpdateCoordinator, location: Location
+    ) -> None:
         """Initialize a Canary security camera."""
         super().__init__(coordinator)
-        self._location_id = location.location_id
-        self._location_name = location.name
+        self._location_id: str = location.location_id
+        self._attr_name = location.name
+        self._attr_unique_id = str(self._location_id)
 
     @property
-    def location(self):
+    def location(self) -> Location:
         """Return information about the location."""
         return self.coordinator.data["locations"][self._location_id]
 
     @property
-    def name(self):
-        """Return the name of the alarm."""
-        return self._location_name
-
-    @property
-    def unique_id(self):
-        """Return the unique ID of the alarm."""
-        return str(self._location_id)
-
-    @property
-    def state(self):
+    def state(self) -> str | None:
         """Return the state of the device."""
         if self.location.is_private:
             return STATE_ALARM_DISARMED
@@ -84,30 +87,25 @@ class CanaryAlarm(CoordinatorEntity, AlarmControlPanelEntity):
         return None
 
     @property
-    def supported_features(self) -> int:
-        """Return the list of supported features."""
-        return SUPPORT_ALARM_ARM_HOME | SUPPORT_ALARM_ARM_AWAY | SUPPORT_ALARM_ARM_NIGHT
-
-    @property
-    def extra_state_attributes(self):
+    def extra_state_attributes(self) -> dict[str, Any]:
         """Return the state attributes."""
         return {"private": self.location.is_private}
 
-    def alarm_disarm(self, code=None):
+    def alarm_disarm(self, code: str | None = None) -> None:
         """Send disarm command."""
         self.coordinator.canary.set_location_mode(
             self._location_id, self.location.mode.name, True
         )
 
-    def alarm_arm_home(self, code=None):
+    def alarm_arm_home(self, code: str | None = None) -> None:
         """Send arm home command."""
         self.coordinator.canary.set_location_mode(self._location_id, LOCATION_MODE_HOME)
 
-    def alarm_arm_away(self, code=None):
+    def alarm_arm_away(self, code: str | None = None) -> None:
         """Send arm away command."""
         self.coordinator.canary.set_location_mode(self._location_id, LOCATION_MODE_AWAY)
 
-    def alarm_arm_night(self, code=None):
+    def alarm_arm_night(self, code: str | None = None) -> None:
         """Send arm night command."""
         self.coordinator.canary.set_location_mode(
             self._location_id, LOCATION_MODE_NIGHT
