@@ -70,6 +70,7 @@ WALLETS = {
     "CHZ": "CHZ",
     "CLF": "CLF",
     "CLP": "CLP",
+    "CLV": "CLV",
     "CNH": "CNH",
     "CNY": "CNY",
     "COMP": "COMP",
@@ -99,6 +100,7 @@ WALLETS = {
     "ETH": "ETH",
     "ETH2": "ETH2",
     "EUR": "EUR",
+    "FET": "FET",
     "FIL": "FIL",
     "FJD": "FJD",
     "FKP": "FKP",
@@ -206,6 +208,7 @@ WALLETS = {
     "SCR": "SCR",
     "SEK": "SEK",
     "SGD": "SGD",
+    "SHIB": "SHIB",
     "SHP": "SHP",
     "SKL": "SKL",
     "SLL": "SLL",
@@ -311,6 +314,7 @@ RATES = {
     "CHF": "CHF",
     "CLF": "CLF",
     "CLP": "CLP",
+    "CLV": "CLV",
     "CNH": "CNH",
     "CNY": "CNY",
     "COMP": "COMP",
@@ -337,6 +341,7 @@ RATES = {
     "ETH": "ETH",
     "ETH2": "ETH2",
     "EUR": "EUR",
+    "FET": "FET",
     "FIL": "FIL",
     "FJD": "FJD",
     "FKP": "FKP",
@@ -435,6 +440,7 @@ RATES = {
     "SCR": "SCR",
     "SEK": "SEK",
     "SGD": "SGD",
+    "SHIB": "SHIB",
     "SHP": "SHP",
     "SKL": "SKL",
     "SLL": "SLL",
