@@ -1,17 +1,13 @@
 """Component to configure Home Assistant via an API."""
 import asyncio
+from http import HTTPStatus
 import importlib
 import os
 
 import voluptuous as vol
 
 from homeassistant.components.http import HomeAssistantView
-from homeassistant.const import (
-    CONF_ID,
-    EVENT_COMPONENT_LOADED,
-    HTTP_BAD_REQUEST,
-    HTTP_NOT_FOUND,
-)
+from homeassistant.const import CONF_ID, EVENT_COMPONENT_LOADED
 from homeassistant.core import callback
 from homeassistant.exceptions import HomeAssistantError
 from homeassistant.setup import ATTR_COMPONENT
@@ -125,7 +121,7 @@ class BaseEditConfigView(HomeAssistantView):
             value = self._get_value(hass, current, config_key)
 
         if value is None:
-            return self.json_message("Resource not found", HTTP_NOT_FOUND)
+            return self.json_message("Resource not found", HTTPStatus.NOT_FOUND)
 
         return self.json(value)
 
@@ -134,12 +130,12 @@ class BaseEditConfigView(HomeAssistantView):
         try:
             data = await request.json()
         except ValueError:
-            return self.json_message("Invalid JSON specified", HTTP_BAD_REQUEST)
+            return self.json_message("Invalid JSON specified", HTTPStatus.BAD_REQUEST)
 
         try:
             self.key_schema(config_key)
         except vol.Invalid as err:
-            return self.json_message(f"Key malformed: {err}", HTTP_BAD_REQUEST)
+            return self.json_message(f"Key malformed: {err}", HTTPStatus.BAD_REQUEST)
 
         hass = request.app["hass"]
 
@@ -151,7 +147,9 @@ class BaseEditConfigView(HomeAssistantView):
             else:
                 self.data_schema(data)
         except (vol.Invalid, HomeAssistantError) as err:
-            return self.json_message(f"Message malformed: {err}", HTTP_BAD_REQUEST)
+            return self.json_message(
+                f"Message malformed: {err}", HTTPStatus.BAD_REQUEST
+            )
 
         path = hass.config.path(self.path)
 
@@ -177,7 +175,7 @@ class BaseEditConfigView(HomeAssistantView):
             path = hass.config.path(self.path)
 
             if value is None:
-                return self.json_message("Resource not found", HTTP_NOT_FOUND)
+                return self.json_message("Resource not found", HTTPStatus.BAD_REQUEST)
 
             self._delete_value(hass, current, config_key)
             await hass.async_add_executor_job(_write, path, current)
