@@ -2,8 +2,9 @@
 from __future__ import annotations
 
 import asyncio
+from collections.abc import Iterable
 import logging
-from typing import Any, Iterable
+from typing import Any
 
 from homeassistant.components.cover import (
     ATTR_CURRENT_POSITION,
