@@ -5,11 +5,10 @@ import logging
 
 import voluptuous as vol
 
-from homeassistant.components.sensor import PLATFORM_SCHEMA
+from homeassistant.components.sensor import PLATFORM_SCHEMA, SensorEntity
 from homeassistant.const import CONF_HOST, CONF_PORT, PERCENTAGE
 from homeassistant.exceptions import PlatformNotReady
 import homeassistant.helpers.config_validation as cv
-from homeassistant.helpers.entity import Entity
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -96,7 +95,7 @@ def setup_platform(hass, config, add_entities, discovery_info=None):
     add_entities(dev, True)
 
 
-class CupsSensor(Entity):
+class CupsSensor(SensorEntity):
     """Representation of a CUPS sensor."""
 
     def __init__(self, data, printer):
@@ -112,7 +111,7 @@ class CupsSensor(Entity):
         return self._name
 
     @property
-    def state(self):
+    def native_value(self):
         """Return the state of the sensor."""
         if self._printer is None:
             return None
@@ -131,7 +130,7 @@ class CupsSensor(Entity):
         return ICON_PRINTER
 
     @property
-    def device_state_attributes(self):
+    def extra_state_attributes(self):
         """Return the state attributes of the sensor."""
         if self._printer is None:
             return None
@@ -155,7 +154,7 @@ class CupsSensor(Entity):
         self._available = self.data.available
 
 
-class IPPSensor(Entity):
+class IPPSensor(SensorEntity):
     """Implementation of the IPPSensor.
 
     This sensor represents the status of the printer.
@@ -184,7 +183,7 @@ class IPPSensor(Entity):
         return self._available
 
     @property
-    def state(self):
+    def native_value(self):
         """Return the state of the sensor."""
         if self._attributes is None:
             return None
@@ -193,7 +192,7 @@ class IPPSensor(Entity):
         return PRINTER_STATES.get(key, key)
 
     @property
-    def device_state_attributes(self):
+    def extra_state_attributes(self):
         """Return the state attributes of the sensor."""
         if self._attributes is None:
             return None
@@ -232,7 +231,7 @@ class IPPSensor(Entity):
         self._available = self.data.available
 
 
-class MarkerSensor(Entity):
+class MarkerSensor(SensorEntity):
     """Implementation of the MarkerSensor.
 
     This sensor represents the percentage of ink or toner.
@@ -258,7 +257,7 @@ class MarkerSensor(Entity):
         return ICON_MARKER
 
     @property
-    def state(self):
+    def native_value(self):
         """Return the state of the sensor."""
         if self._attributes is None:
             return None
@@ -266,12 +265,12 @@ class MarkerSensor(Entity):
         return self._attributes[self._printer]["marker-levels"][self._index]
 
     @property
-    def unit_of_measurement(self):
+    def native_unit_of_measurement(self):
         """Return the unit of measurement."""
         return PERCENTAGE
 
     @property
-    def device_state_attributes(self):
+    def extra_state_attributes(self):
         """Return the state attributes of the sensor."""
         if self._attributes is None:
             return None
