@@ -1,5 +1,14 @@
 """Support for deCONZ binary sensors."""
-from pydeconz.sensor import CarbonMonoxide, Fire, OpenClose, Presence, Vibration, Water
+from pydeconz.sensor import (
+    Alarm,
+    CarbonMonoxide,
+    Fire,
+    GenericFlag,
+    OpenClose,
+    Presence,
+    Vibration,
+    Water,
+)
 
 from homeassistant.components.binary_sensor import (
     DEVICE_CLASS_GAS,
@@ -11,6 +20,7 @@ from homeassistant.components.binary_sensor import (
     DEVICE_CLASS_VIBRATION,
     DOMAIN,
     BinarySensorEntity,
+    BinarySensorEntityDescription,
 )
 from homeassistant.const import ATTR_TEMPERATURE
 from homeassistant.core import callback
@@ -20,17 +30,46 @@ from .const import ATTR_DARK, ATTR_ON, NEW_SENSOR
 from .deconz_device import DeconzDevice
 from .gateway import get_gateway_from_config_entry
 
+DECONZ_BINARY_SENSORS = (
+    Alarm,
+    CarbonMonoxide,
+    Fire,
+    GenericFlag,
+    OpenClose,
+    Presence,
+    Vibration,
+    Water,
+)
+
 ATTR_ORIENTATION = "orientation"
 ATTR_TILTANGLE = "tiltangle"
 ATTR_VIBRATIONSTRENGTH = "vibrationstrength"
 
-DEVICE_CLASS = {
-    CarbonMonoxide: DEVICE_CLASS_GAS,
-    Fire: DEVICE_CLASS_SMOKE,
-    OpenClose: DEVICE_CLASS_OPENING,
-    Presence: DEVICE_CLASS_MOTION,
-    Vibration: DEVICE_CLASS_VIBRATION,
-    Water: DEVICE_CLASS_MOISTURE,
+ENTITY_DESCRIPTIONS = {
+    CarbonMonoxide: BinarySensorEntityDescription(
+        key="carbonmonoxide",
+        device_class=DEVICE_CLASS_GAS,
+    ),
+    Fire: BinarySensorEntityDescription(
+        key="fire",
+        device_class=DEVICE_CLASS_SMOKE,
+    ),
+    OpenClose: BinarySensorEntityDescription(
+        key="openclose",
+        device_class=DEVICE_CLASS_OPENING,
+    ),
+    Presence: BinarySensorEntityDescription(
+        key="presence",
+        device_class=DEVICE_CLASS_MOTION,
+    ),
+    Vibration: BinarySensorEntityDescription(
+        key="vibration",
+        device_class=DEVICE_CLASS_VIBRATION,
+    ),
+    Water: BinarySensorEntityDescription(
+        key="water",
+        device_class=DEVICE_CLASS_MOISTURE,
+    ),
 }
 
 
@@ -46,13 +85,12 @@ async def async_setup_entry(hass, config_entry, async_add_entities):
 
         for sensor in sensors:
 
+            if not gateway.option_allow_clip_sensor and sensor.type.startswith("CLIP"):
+                continue
+
             if (
-                sensor.BINARY
-                and sensor.uniqueid not in gateway.entities[DOMAIN]
-                and (
-                    gateway.option_allow_clip_sensor
-                    or not sensor.type.startswith("CLIP")
-                )
+                isinstance(sensor, DECONZ_BINARY_SENSORS)
+                and sensor.unique_id not in gateway.entities[DOMAIN]
             ):
                 entities.append(DeconzBinarySensor(sensor, gateway))
 
@@ -84,7 +122,9 @@ class DeconzBinarySensor(DeconzDevice, BinarySensorEntity):
     def __init__(self, device, gateway):
         """Initialize deCONZ binary sensor."""
         super().__init__(device, gateway)
-        self._attr_device_class = DEVICE_CLASS.get(type(self._device))
+
+        if entity_description := ENTITY_DESCRIPTIONS.get(type(device)):
+            self.entity_description = entity_description
 
     @callback
     def async_update_callback(self, force_update=False):
@@ -116,8 +156,8 @@ class DeconzBinarySensor(DeconzDevice, BinarySensorEntity):
 
         elif self._device.type in Vibration.ZHATYPE:
             attr[ATTR_ORIENTATION] = self._device.orientation
-            attr[ATTR_TILTANGLE] = self._device.tiltangle
-            attr[ATTR_VIBRATIONSTRENGTH] = self._device.vibrationstrength
+            attr[ATTR_TILTANGLE] = self._device.tilt_angle
+            attr[ATTR_VIBRATIONSTRENGTH] = self._device.vibration_strength
 
         return attr
 
