@@ -1,4 +1,5 @@
 """Base class for deCONZ devices."""
+
 from homeassistant.core import callback
 from homeassistant.helpers.device_registry import CONNECTION_ZIGBEE
 from homeassistant.helpers.dispatcher import async_dispatcher_connect
@@ -18,15 +19,15 @@ class DeconzBase:
     @property
     def unique_id(self):
         """Return a unique identifier for this device."""
-        return self._device.uniqueid
+        return self._device.unique_id
 
     @property
     def serial(self):
         """Return a serial number for this device."""
-        if self._device.uniqueid is None or self._device.uniqueid.count(":") != 7:
+        if self._device.unique_id is None or self._device.unique_id.count(":") != 7:
             return None
 
-        return self._device.uniqueid.split("-", 1)[0]
+        return self._device.unique_id.split("-", 1)[0]
 
     @property
     def device_info(self):
@@ -34,22 +35,22 @@ class DeconzBase:
         if self.serial is None:
             return None
 
-        bridgeid = self.gateway.api.config.bridgeid
-
         return {
             "connections": {(CONNECTION_ZIGBEE, self.serial)},
             "identifiers": {(DECONZ_DOMAIN, self.serial)},
             "manufacturer": self._device.manufacturer,
-            "model": self._device.modelid,
+            "model": self._device.model_id,
             "name": self._device.name,
-            "sw_version": self._device.swversion,
-            "via_device": (DECONZ_DOMAIN, bridgeid),
+            "sw_version": self._device.software_version,
+            "via_device": (DECONZ_DOMAIN, self.gateway.api.config.bridge_id),
         }
 
 
 class DeconzDevice(DeconzBase, Entity):
     """Representation of a deCONZ device."""
 
+    _attr_should_poll = False
+
     TYPE = ""
 
     def __init__(self, device, gateway):
@@ -57,16 +58,7 @@ class DeconzDevice(DeconzBase, Entity):
         super().__init__(device, gateway)
         self.gateway.entities[self.TYPE].add(self.unique_id)
 
-    @property
-    def entity_registry_enabled_default(self):
-        """Return if the entity should be enabled when first added to the entity registry.
-
-        Daylight is a virtual sensor from deCONZ that should never be enabled by default.
-        """
-        if self._device.type == "Daylight":
-            return False
-
-        return True
+        self._attr_name = self._device.name
 
     async def async_added_to_hass(self):
         """Subscribe to device events."""
@@ -96,13 +88,3 @@ class DeconzDevice(DeconzBase, Entity):
     def available(self):
         """Return True if device is available."""
         return self.gateway.available and self._device.reachable
-
-    @property
-    def name(self):
-        """Return the name of the device."""
-        return self._device.name
-
-    @property
-    def should_poll(self):
-        """No polling needed."""
-        return False
